#!/bin/bash
# Copyright (c) Huawei Technologies Co., Ltd. 2017-2020. All rights reserved.
function bep_deploy_env()
{
    bep_log "INFO" "**** Phase Deploy BEP_ENV BEGIN ***********************"
    local buildtrace_enable="$1"
    local bep_conf_file_name="$2"
    local bep_path="$3"
    local bep_time_key_name="$4"

    local bep_export_file=`LD_PRELOAD= mktemp /tmp/bep_export.XXXXXX`
    ##Step Zero: Save the primitive environment##
    local primitive_env="$(env | sort)"
    bep_log "INFO" "Step 1: Save bep_related variables(LC_ TZ) in previous environment into SAVED_BEP_RELATED_ENV. You can recover it with -u."
    bep_save_related_env
    bep_log "INFO" "Step 2: Clean up bep_related variables in previous environment in case BEP_ or LC_ pollution"
    bep_unset_env
    bep_log "INFO" "Step 3: Generate $bep_export_file, which is used to deploy the bep environment"
    local bep_time=$(grep "^$bep_time_key_name=" "$bep_conf_file_name" | awk -F= '{ print $2 }')
    if [ -z "$bep_time" ]; then
        bep_time=$(grep "^bep_timestamp=" "$bep_conf_file_name" | awk -F= '{ print $2 }')
    fi
    bep_log INFO "Extra : get bep_timestamp : $bep_time"
    {
        echo "export BEP_TIME=$bep_time"
        grep -E "^BEP|^TZ|^LC|^SOURCE_DATE_EPOCH" "$bep_conf_file_name" | xargs -0  | awk -F= '{ if($1&&$2!="") { print "export "$1"=""\""$2"\"" } }'
        grep -E "^PYTHONHASHSEED|^PERL_HASH_SEED" "$bep_conf_file_name" | xargs -0  | awk -F= '{ if($1) {print "export "$1"=""\""$2"\"" } }'
    } > "$bep_export_file"

    bep_log "INFO" "Step 4: Deploy bep environment"
    ##Step Four: set bepkit environment varible##
    source "$bep_export_file"
    if [[ "$SOURCE_DATE_EPOCH" == "yes" ]]; then
	export SOURCE_DATE_EPOCH=$[`(date --date="${BEP_TIME/,/ }" +%s)` + $[8*60*60]]
    fi
    if [[ -z "$BEP_UID" || -z "$BEP_GID" ]]; then
        unset BEP_UIDLIST
    fi
    if [[ $BEP_UID == 0 ]]; then
        bep_log INFO "INFO : Set BEP_UID = 0 will change the owner of file to root."
    fi
    if [[ $BEP_GID == 0 ]]; then
        bep_log INFO "INFO : Set BEP_GID = 0 will change the group of file to root."
    fi
    if [[ "$buildtrace_enable" == "yes" ]]; then
        export BEP_TRACE_ENABLE=yes
    fi
    if [[ "$BEP_TRACE_ENABLE" == "yes" ]]; then
        bep_log "INFO" "Enable bep_trace when BEP_TRACE_ENABLE is yes"
        bep_enable_trace "$bep_path"
        if [[ "$?" != "0" ]]; then
            return 1
        fi
        if [[ ! -z "$BEP_TRACE_TEMPLATE" ]]; then
            bep_log "INFO" "Enable bep_trace_template "
            bep_enable_trace_template  "$bep_path"
            if [[ "$?" != "0" ]]; then
                return 1
            fi
        fi
    fi

    bep_log "INFO" "Step 5: Enable BepKit"
    if [[ -z "$LD_PRELOAD" ]];then
        export LD_PRELOAD=$BEP_LIB_SOFT_LINK
    elif [[ "$LD_PRELOAD" =~ "$BEP_LIB_SOFT_LINK" ]]; then
        bep_log INFO "Extra : LD_PRELOAD has contained $BEP_LIB_SOFT_LINK, deploy bep environment again."
    else
        export LD_PRELOAD=$LD_PRELOAD:$BEP_LIB_SOFT_LINK
    fi

    bep_log "INFO" "Step 6: Check whether the bep environment is deployed or not"
    local bep_date1="$(TZ=Asia/Shanghai date --date="${bep_time/,/ }" +%s)"
    local bep_date2="$(TZ=Asia/Shanghai BEP_GTDLIST=date BEP_CGTLIST=date date +%s)"
    if [[ $? = 0 ]] && [[ "$bep_date1" == "$bep_date2" ]];then
        bep_log "INFO" "Deploy BEP_ENV successful, BEP_TIME=$bep_time"
    else 
        bep_recover_env
        if [[ "$(env | sort)" == "$primitive_env" ]]; then
            bep_log "ERROR" "Deploy BEP_ENV fail and recover the primitive env"
        else
            bep_log "ERROR" "Deploy BEP_ENV fail, and fail in recovering the primitive env"
        fi
        return 1
    fi
    bep_log "INFO" "**** Phase Deploy BEP_ENV END ***********************"
    return 0
}
