#!/bin/bash
# Copyright (c) Huawei Technologies Co., Ltd. 2017-2020. All rights reserved.

function bep_enable_trace_template()
{
    bep_path="$1"
    if [[ ! -f "$BEP_TRACE_TEMPLATE" ]]; then
        bep_log "INFO" "Extra : $BEP_TRACE_TEMPLATE doesn't exist "
    fi
    return 0
}

function bep_enable_trace()
{
    bep_path="$1"
    bep_log "INFO" "Extra : Enable bepkit trace ..."
    if [[ ! -f "$BEP_INSTALL_DIR/sqlite3/bepkit_trace.db" ]] && [[ ! -f "$bep_path/sqlite3/bepkit_trace.db" ]]; then
        return 1
    fi
    if [[ -z "$BEP_TRACE_OUTPUT" ]]; then
        bep_log "INFO" "Extra : it do not record date to datebase for BEP_TRACE_OUTPUT is not set"
    else
        if [[ ! -d "$(dirname "$BEP_TRACE_OUTPUT")" ]]; then
            bep_log "ERROR" "BEP_TRACE_OUTPUT: $(dirname "$BEP_TRACE_OUTPUT") is not exist."
            return 1
        fi
        if [[ -f "${BEP_TRACE_OUTPUT}" ]]; then
            return 0
        fi
        if [[ -f "$bep_path/sqlite3/bepkit_trace.db" ]]; then
            \cp -af "$bep_path/sqlite3/bepkit_trace.db" "${BEP_TRACE_OUTPUT}"
        else
            \cp -af "$BEP_INSTALL_DIR/sqlite3/bepkit_trace.db" "${BEP_TRACE_OUTPUT}"
        fi
        bep_log "INFO" "Extra : Init bep sqlite datebase ${BEP_TRACE_OUTPUT}"
    fi
    return 0
}

function bep_unset_env()
{
    local BEP_ENV
    BEP_ENV="BEP_UID BEP_GID BEP_HOSTNAME BEP_INODE BEP_TRACE_ENABLE BEP_TRACE_OUTPUT BEP_TRACE_TEMPLATE BEP_TRACE_MAP BEP_TIMELIST BEP_CGTLIST BEP_FILE_TIME_LIST BEP_WHITELIST BEP_GTDLIST BEP_PRO_TIMES_LIST BEP_DIRLIST BEP_DIRONCELIST BEP_NFTWLIST BEP_UIDLIST BEP_DEVIDLIST BEP_RANDOMLIST BEP_NAMELIST BEP_RANDOM_RECORD_OUTPUT BEP_TIME"
    unset $BEP_ENV
    unset "${BEP_RELATED_VARIABLES[@]}"
}

function bep_save_related_env()
{
    if [[ "$LD_PRELOAD" =~ "$BEP_LIB_SOFT_LINK" ]];then
        return 0
    fi
    local bep_related_env=""
    for bep_item in "${BEP_RELATED_VARIABLES[@]}"; do
        bep_item_value="$(eval echo "\$$bep_item")"
        if [[ -n "$bep_item_value" ]]; then
            bep_related_env="$bep_related_env $bep_item=\"$bep_item_value\""
            bep_log "INFO" "bep_related_env is $bep_related_env."
        fi
    done
    export SAVED_BEP_RELATED_ENV="$bep_related_env"
    if [[ -n "$LD_PRELOAD" ]]; then
        export SAVED_BEP_LD_PRELOAD="$LD_PRELOAD"
    fi
}

function bep_recover_env()
{
    bep_log "INFO" "**** Phase Recover BEP_ENV BEGIN ***********************"
    bep_unset_env
    if [[ -n "$SAVED_BEP_RELATED_ENV" ]]; then
        local bep_recover_file=`LD_PRELOAD= mktemp /tmp/bep_revover.XXXXXX`
        for saved_bep_item in $SAVED_BEP_RELATED_ENV; do
            bep_log "INFO" "Recover $saved_bep_item."
            echo "export $saved_bep_item" >> "$bep_recover_file"
        done
        unset SAVED_BEP_RELATED_ENV
        source "$bep_recover_file"
        \rm -f "$bep_recover_file"
        bep_log "INFO" "Recover the primitive environment(LC_ TZ) when SAVED_BEP_RELATED_ENV exists."
    fi
    unset SAVED_BEP_RELATED_ENV
    if [[ -n "$SAVED_BEP_LD_PRELOAD" ]]; then
        bep_log "INFO" "Recover the primitive value of LD_PRELOAD when SAVED_BEP_LD_PRELOAD exists."
        unset SAVED_BEP_LD_PRELOAD
        echo "export LD_PRELOAD=\""$SAVED_BEP_LD_PRELOAD"\" " >> "$bep_revover_file"
    else
        unset LD_PRELOAD
    fi
    unset SAVED_BEP_LD_PRELOAD
    bep_log "INFO" "**** Phase Recover BEP_ENV END ***********************"
}
