#!/bin/bash
# Copyright (c) Huawei Technologies Co., Ltd. 2017-2020. All rights reserved.

function bep_refresh_timestamp()
{
    local bep_conf_file_name="$1"
    local bep_timestamp_section_name="$2"
    local bep_cur_section_name=""
    local bep_line=""
    local bep_first_char=""
    local bep_timestamp_key=""
    local bep_current_time=""
    local bep_env_conf_tmp=`LD_PRELOAD= mktemp /tmp/bep_env.conf.XXXXXX`
    if [[ ! -f "$bep_conf_file_name" ]]; then
        bep_log "ERROR" "$bep_conf_file_name does not exist."
        return 1
    fi
    if [[ "$bep_conf_file_name" == "$BEP_INSTALL_DIR/bep_env.conf" ]] && [[ "$(whoami)" != "root" ]]; then
        bep_log "ERROR" "$bep_conf_file_name can only be refreshed by root."
        return 1
    fi
    if [[ -z "$bep_timestamp_section_name" ]]; then
        bep_timestamp_section_name="timestamp"
    fi
    #---------------------------------------------------
    #To test whether the section name is right?
    #---------------------------------------------------
    bep_cur_section_name=$(grep "^\[${bep_timestamp_section_name}\]" "$bep_conf_file_name")
    if [[ "$bep_cur_section_name" != "[$bep_timestamp_section_name]" ]]; then
        bep_log ERROR "The $bep_timestamp_section_name section is not included in $bep_conf_file_name"
        return 1
    fi
    #---------------------------------------------------
    #Generate timestamp and write into bepbuildtime file
    #---------------------------------------------------
    bep_current_time=$(LD_PRELOAD='' date "+%s")
    bep_cur_section_name=""
    while read bep_line
    do
        if test -z "$bep_line"; then
            echo "$bep_line" >> "$bep_env_conf_tmp"
            continue
        fi
        bep_first_char=${bep_line:0:1}
        if [ '#' == "$bep_first_char" ]; then
            echo "$bep_line" >> "$bep_env_conf_tmp"
            continue
        fi
        if [ '[' == "$bep_first_char" ]; then
            echo "$bep_line" >> "$bep_env_conf_tmp"
            bep_cur_section_name="${bep_line#*[}"
            bep_cur_section_name="${bep_cur_section_name%]*}"
            continue
        else
            if [ "$bep_cur_section_name" = "$bep_timestamp_section_name" ]
            then
                bep_timestamp_key=$(echo "${bep_line%=*}" |sed s/[[:space:]]//g)
                if test -n "$bep_timestamp_key"; then
                    echo "$bep_timestamp_key=$(date -d @"$bep_current_time" "+%F,%T")" >> "$bep_env_conf_tmp"
                fi
            else
                echo "$bep_line" >> "$bep_env_conf_tmp"
            fi
        fi
        bep_current_time=$((bep_current_time-=600))
    done < "$bep_conf_file_name"
    chmod 644 "$bep_env_conf_tmp"
    \mv "$bep_env_conf_tmp" "$bep_conf_file_name"
    bep_log INFO "The value in section $bep_timestamp_section_name in $bep_conf_file_name has been refreshed."
    return 0
}
