#!/bin/bash
# Copyright (c) Huawei Technologies Co., Ltd. 2017-2020. All rights reserved.


function bep_show_help()
{
    local bep_usage="
    Usage:
            source bep_env.sh -s  [CONF] [KEY_TIME]
            source bep_env.sh -t -s  [CONF] [KEY_TIME]
        or: source bep_env.sh -u
        or: bep_env.sh -c  [CONF] [SECTION]
        or: bep_env.sh -rb [CONF] [SECTION]
        or: bep_env.sh -v
        or: bep_env.sh -h

    Options:
        -t enable buildtrace
        -s deploy bep environment with the related variables in bep_env.conf
        -u unset all the BEP realted variables and recover the primitive environment(LC_ TZ) before the last bep-deployment.
        -c refresh the value of timestamp in bep_env.conf with the latest time.
        -rb check and read the value of timestamp in bep_env.conf.
        -h  display this help messages and exit.
        -v  display version messages and exit.
        [CONF] specify the CONF file. if not set, search bep_env.conf in the current path.
        [KEY_TIME] specify the name of key. if not set, the name is bep_timestamp.
        [SECTION] specify the name of time section. if not set, the name is timestamp.

    CONF:
        [Section]
        key=value

    "
    bep_log "INFO" "$bep_usage"
}


function bep_get_os_version()
{
    local cur_os_version=""
    local help_message=""
    local readonly empty_prefix=""
    if [[ -f "$empty_prefix/etc/redhat-release" ]]; then
        help_message=$(cat "$empty_prefix/etc/redhat-release")
        help_message="$(echo $help_message | tr 'A-Z' 'a-z')" #uptolow
        if [[ "$help_message" = *"centos"* ]];then
            cur_os_version="centos"
        fi
        if [[ "$help_message" = *"redhat"* || "$help_message" = *"red hat"* ]];then
            cur_os_version="redhat"
        fi
        if [[ "$help_message" = *"euler"* ]];then
            cur_os_version="euler"
        fi
    elif [[ -f "$empty_prefix/etc/euleros-release" ]]; then
        help_message=$(cat "$empty_prefix/etc/euleros-release")
        help_message="$(echo $help_message | tr 'A-Z' 'a-z')" #uptolow
        if [[ "$help_message" = *"euler"* ]];then
            cur_os_version="euler"
        fi
    else
        help_message=$(cat "$empty_prefix/etc/issue")
        help_message="$(uname -a):$help_message"
        help_message="$(echo $help_message | tr 'A-Z' 'a-z')"
        if [[ "$help_message" = *"ubuntu"* ]];then
            cur_os_version="ubuntu"
        fi
        if [[ "$help_message" = *"debian"* ]];then
            cur_os_version="debian"
        fi
        if [[ "$help_message" = *"suse"* ]];then
            cur_os_version="suse"
        fi
    fi
    echo "$cur_os_version"
}

function bep_init_gloabl_variables()
{
    local cur_os_version=$(bep_get_os_version)
    BEP_EMPTY_PREFIX=""
    BEP_VERSION_NUMBER=2.1.T1
    BEP_LIB_REAL_NAME="libbep_env.so.$BEP_VERSION_NUMBER"
    BEP_LIB_SOFT_LINK="libbep_env.so"
    BEP_SHELL_NAME="bep_env.sh"
    BEP_PYTHON_NAME="bep_env.py"
    BEP_CONF_NAME="bep_env.conf"
    BEP_VERSION="secBepkit$BEP_VERSION_NUMBER"
    BEP_INSTALL_DIR="$BEP_EMPTY_PREFIX/opt/buildtools/$BEP_VERSION"
    BEP_BIN_DIR="$BEP_EMPTY_PREFIX/usr/local/bin"
    BEP_WORK_ARCH=`arch`
    BEP_WORK_ARCH=`arch`
    # LD_PRELOAD is particular, because it may include space.
    BEP_RELATED_VARIABLES=(PERL_HASH_SEED PYTHONHASHSEED TZ SOURCE_DATE_EPOCH LC_ALL \
                        LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES LC_PAPER \
                        LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT LC_IDENTIFICATION)
    case "$cur_os_version" in
    ubuntu|debian)
        if [[ "$BEP_WORK_ARCH" == "aarch64"* ]];then
            BEP_LIB_SOFT_LINK_64="$BEP_EMPTY_PREFIX/usr/lib/aarch64-linux-gnu/$BEP_LIB_SOFT_LINK"
        else
            BEP_LIB_SOFT_LINK_64="$BEP_EMPTY_PREFIX/usr/lib/x86_64-linux-gnu/$BEP_LIB_SOFT_LINK"
            BEP_LIB_SOFT_LINK_32="$BEP_EMPTY_PREFIX/usr/lib32/$BEP_LIB_SOFT_LINK"
        fi
        ;;
    *)
        BEP_LIB_SOFT_LINK_64="$BEP_EMPTY_PREFIX/usr/lib64/$BEP_LIB_SOFT_LINK"
        BEP_LIB_SOFT_LINK_32="$BEP_EMPTY_PREFIX/usr/lib/$BEP_LIB_SOFT_LINK"
        ;;
    esac
}
