#!/bin/bash
# Copyright (c) Huawei Technologies Co., Ltd. 2017-2020. All rights reserved.
function bep_log()
{
    local logtype="$1"
    local logtext="$2"
    case "$logtype" in
    INFO)
        echo -e "$(LD_PRELOAD="" date +%F_%T) $logtype $logtext"
        ;;
    ERROR)
        echo -e "\033[31m$(LD_PRELOAD="" date +%F_%T) $logtype $logtext\033[0m"
        ;;
    WARNING)
        echo -e "\033[33m$(LD_PRELOAD="" date +%F_%T) $logtype $logtext\033[0m"
        ;;
    esac
}

function bep_check_completeness()
{
    if [[ ! -d "$BEP_INSTALL_DIR" ]] || [[ ! -d "$BEP_INSTALL_DIR/bep_env" ]] || [[ ! -d "$BEP_INSTALL_DIR/auto" ]]
    then
        return 1
    fi
    if [[ ! -s "$BEP_INSTALL_DIR/$BEP_SHELL_NAME" ]] || [[ ! -x "$BEP_INSTALL_DIR/$BEP_SHELL_NAME" ]]; then
        return 1
    fi
    if [[ ! -L "$BEP_LIB_SOFT_LINK_64" ]]; then
        return 1
    fi
    if [[ "$(readlink -f "$BEP_BIN_DIR/$BEP_SHELL_NAME")" != "$BEP_INSTALL_DIR/$BEP_SHELL_NAME" ]]; then
        return 1
    fi
    return 0
}

function bep_recover_set_config()
{
    local primitive_set_config="$1"
    local primitive_set_o_pipefail_config="$2"
    # Recovery the primitive set config
    if [[ "$primitive_set_config" =~ "u" ]]; then
        set -u
    fi
    if [[ "$primitive_set_config" =~ "e" ]]; then
        set -e
    fi
    # Recovery the primitive set -o pipefail config
    if [[ "$primitive_set_o_pipefail_config" == *"on"* ]]; then
        set -o pipefail
    fi
    if [[ "$-" != "$primitive_set_config" ]] || [[ "$(set -o | grep pipefail)" != "$primitive_set_o_pipefail_config" ]]
    then
        bep_log "ERROR" "Step 1:  Fail in recovering the primitive set -euo pipefail configuration"
        return 1
    fi
    return 0
}


function bep_unset_global_variables()
{
    unset BEP_EMPTY_PREFIX
    unset BEP_LIB_REAL_NAME
    unset BEP_LIB_SOFT_LINK

    unset BEP_SHELL_NAME
    unset BEP_PYTHON_NAME
    unset BEP_CONF_NAME
    unset BEP_VERSION
    unset BEP_INSTALL_DIR
    unset BEP_BIN_DIR
    unset BEP_LIB_SOFT_LINK_64
    unset BEP_LIB_SOFT_LINK_32
}

function bep_unset_involved_func()
{
    unset bep_refresh_timestamp
    unset bep_check_timestamp
    unset bep_deploy_env
    unset bep_show_help
    unset bep_show_version
    unset bep_generate_saved_export_file
    unset bep_generate_unset_file
    unset bep_enable_trace

    unset bep_get_os_version
    unset bep_init_gloabl_variables
    unset bep_check_completeness
    unset bep_recover_set_config
    unset bep_unset_global_variables
}
