#!/bin/bash
# Copyright (c) Huawei Technologies Co., Ltd. 2017-2020. All rights reserved.
# secBepKit version 2.1.T1

function bep_main()
{
    # Step 1: Save the primitive set -euo pipefail configuration
    local primitive_set_config="$-"
    local primitive_set_o_pipefail_config="$(set -o | grep pipefail)"
    # It is necessary for bep to get the system environment variables.
    # "set -u" will make the command [[ -n "LC_ALL"]] fail when "LC_ALL" does not exist
    set +euo pipefail
    if [[ "$1" == "-t" ]]; then
        buildtrace_enable="yes"
        shift
    else
        buildtrace_enable="no"
    fi
    local bep_option="$1"
    local bep_invoke_mode=""
    # Step 2: check invoke mode
    if [[ "${BASH_SOURCE[0]}" != "$0" ]]; then
        if [[ "$0" == "-bash" ]] || [[ "$0" == "sh" ]]; then
            # Execute with source in bash
            bep_invoke_mode="1"
        else
            # Execute with source in script
            bep_invoke_mode="2"
        fi
        if [[ "$bep_option" == "-c" ]] || [[ "$bep_option" == "-rb" ]] || [[ "$bep_option" == "-v" ]]; then
            echo -e "\033[31m$(LD_PRELOAD="" date +%F_%T) ERROR Option $bep_option needs executing without source.\033[0m"
            return 0
        fi
    else
        # Execute without source
        bep_invoke_mode="0"
        if [[ "$bep_option" == "-s" ]] || [[ "$bep_option" == "-u" ]]; then
            echo -e "\033[31m$(LD_PRELOAD="" date +%F_%T) ERROR Option $bep_option needs executing with source.\033[0m"
            return 0
        fi
    fi

    # Step 3: locate_real_script when execute by soft link and
    local bep_script="${BASH_SOURCE[0]}"
    local bep_real_script="$bep_script"
    if [[ -L "$bep_script" ]]; then
        bep_real_script="$(readlink -f "$bep_script")"
    fi
    # Step 4: import subscript in auto and define the global variables used to the following steps
    local bep_path="$(cd "$(dirname "$bep_real_script")" || return; pwd)"
    if [[ -z "$bep_path" ]];then
        bep_path="."
    fi
    . "$bep_path"/auto/bep_deploy_env.sh
    . "$bep_path"/auto/bep_deploy_env_util.sh
    . "$bep_path"/auto/bep_check_timestamp.sh
    . "$bep_path"/auto/bep_refresh_timestamp.sh
    . "$bep_path"/auto/bep_show_help.sh
    . "$bep_path"/auto/bep_util.sh

    bep_init_gloabl_variables

    # Step 5: Check the completeness of secBepkit-2.1.T1 in current os environment
    #bep_check_completeness
    #if [[ "$?" != "0" ]]; then
    #    bep_log "ERROR" "Fail in checking the completeness of secBepkit-2.1.T1"
    #    return 1
    #fi

    # Step 6: locate the bep_env.conf
    local bep_conf_file_name="$2"
    if [[ -n "$bep_conf_file_name" ]]; then
        bep_log "INFO" "Use the specified $bep_conf_file_name by user. Please make sure it is correct."
        if [[ ! -f "$bep_conf_file_name" ]]; then
            bep_log "ERROR" "$bep_conf_file_name does not exist."
            return
        fi
    elif [[ "$bep_option" == "-s" ]] || [[ "$bep_option" == "-c" ]] || [[ "$bep_option" == "-rb" ]]; then
        bep_conf_file_name="$bep_path/bep_env.conf"
        bep_log "INFO" "Use the default bep_env.conf in $bep_path."
    fi

    case "$bep_option" in
    -s)
        bep_deploy_env "$buildtrace_enable" "$bep_conf_file_name" "$bep_path" "$3"
        ;;
    -c)
        bep_refresh_timestamp "$bep_conf_file_name" "$3"
        ;;
    -rb)
        bep_check_and_read_timestamp "$bep_conf_file_name" "$3"
        ;;
    -u)
        bep_recover_env
        ;;
    -v)
	if [[ -L "$BEP_LIB_SOFT_LINK_64" ]]; then
            bep_log "INFO" "$(strings "$BEP_LIB_SOFT_LINK_64" | grep "secBepKit version")"
        fi
	if [[ -L "$BEP_LIB_SOFT_LINK_32" ]]; then
            bep_log "INFO" "$(strings "$BEP_LIB_SOFT_LINK_32" | grep "secBepKit version")"
        fi
        ;;
    -i|-e)
        # for compatibility
        ;;
    -h|*)
        bep_show_help
        ;;
    esac
    # Step 7: Reover the primitive set -euo pipefail configuration and "
    bep_recover_set_config "$primitive_set_config" "$primitive_set_o_pipefail_config"
    # Step 8: Cleanup the global variables and involved function in case namespace pollution
    if [[ "$bep_invoke_mode" == "1" ]] || [[ "$bep_invoke_mode" == "2" ]]; then
        bep_unset_global_variables
        bep_unset_involved_func
    fi
    return 0
}

bep_main "$@"
