CREATE TABLE path_file_table (
 id INTEGER PRIMARY KEY,
 filename TEXT NOT NULL,
 UNIQUE (filename)
);

CREATE TABLE tool_file_table (
 id INTEGER PRIMARY KEY,
 filename TEXT NOT NULL,
 checksum TEXT NOT NULL,
 UNIQUE (filename,checksum)
);

CREATE TABLE source_file_table (
 id INTEGER PRIMARY KEY,
 filename TEXT NOT NULL,
 path_file_id INT NOT NULL,
 checksum TEXT NOT NULL,
 command_id INT NOT NULL,
 UNIQUE (filename,path_file_id,checksum)
 FOREIGN KEY(path_file_id) REFERENCES path_file_table(id)
 FOREIGN KEY(command_id) REFERENCES build_command_table(id)
);

CREATE TABLE build_command_table (
 id INTEGER PRIMARY KEY,
 time TEXT NOT NULL,
 command TEXT NOT NULL,
 tool_file_id INT NOT NULL,
 path_file_id INT NOT NULL,
 pid INT NOT NULL,
 runtime INT NOT NULL,
 FOREIGN KEY(tool_file_id) REFERENCES tool_file_table(id),
 FOREIGN KEY(path_file_id) REFERENCES path_file_table(id)
 FOREIGN KEY(pid) REFERENCES build_command_table(id)
);

CREATE TABLE target_file_table (
 id INTEGER PRIMARY KEY,
 filename TEXT NOT NULL,
 path_file_id INT NOT NULL,
 checksum TEXT NOT NULL,
 command_id INT NOT NULL,
 import_id INT NOT NULL,
 UNIQUE (filename,path_file_id,checksum,command_id)
 FOREIGN KEY(path_file_id) REFERENCES path_file_table(id),
 FOREIGN KEY(command_id) REFERENCES build_command_table(id),
 FOREIGN KEY(import_id) REFERENCES build_command_table(id)
);

CREATE TABLE head_file_table (
 id INTEGER PRIMARY KEY,
 filename TEXT NOT NULL,
 path_file_id INT NOT NULL,
 checksum TEXT NOT NULL,
 UNIQUE (filename,path_file_id,checksum)
 FOREIGN KEY(path_file_id) REFERENCES path_file_table(id)
);

CREATE TABLE target_source_table (
 id INTEGER PRIMARY KEY,
 target_file_id INT NOT NULL,
 depend_id INT NOT NULL,
 UNIQUE (target_file_id,depend_id),
 FOREIGN KEY(target_file_id) REFERENCES target_file_table(id),
 FOREIGN KEY(depend_id) REFERENCES source_file_table(id) 
);

CREATE TABLE target_target_table (
 id INTEGER PRIMARY KEY,
 target_file_id INT NOT NULL,
 depend_id INT NOT NULL,
 UNIQUE (target_file_id,depend_id),
 FOREIGN KEY(target_file_id) REFERENCES target_file_table(id),
 FOREIGN KEY(depend_id) REFERENCES target_file_table(id) 
);

CREATE TABLE source_source_table (
 id INTEGER PRIMARY KEY,
 target_file_id INT NOT NULL,
 depend_id INT NOT NULL,
 UNIQUE (target_file_id,depend_id),
 FOREIGN KEY(target_file_id) REFERENCES source_file_table(id),
 FOREIGN KEY(depend_id) REFERENCES source_file_table(id) 
);

CREATE TABLE source_head_table (
 id INTEGER PRIMARY KEY,
 target_file_id INT NOT NULL,
 depend_id INT NOT NULL,
 UNIQUE (target_file_id,depend_id),
 FOREIGN KEY(target_file_id) REFERENCES source_file_table(id),
 FOREIGN KEY(depend_id) REFERENCES head_file_table(id) 
);

CREATE TABLE bep_log_table (
 id INTEGER PRIMARY KEY,
 time TEXT NOT NULL,
 level TEXT NOT NULL,
 info TEXT NOT NULL
);

CREATE TABLE build_time_table (
 id INTEGER PRIMARY KEY,
 build_id INT NOT NULL,
 build_time INT NOT NULL,
 sum_time INT NOT NULL,
 checksum_time INT NOT NULL,
 insert_time INT NOT NULL,
 query_time INT NOT NULL,
 FOREIGN KEY(build_id) REFERENCES build_command_table(id)
);

CREATE INDEX path_index on path_file_table(filename);
CREATE INDEX tool_index on tool_file_table(filename);
CREATE INDEX source_file_index on source_file_table(filename);
CREATE INDEX source_table_index on source_file_table(filename,path_file_id,checksum);
CREATE INDEX target_file_index on target_file_table(filename);
CREATE INDEX target_table_index on target_file_table(filename,path_file_id,checksum);
CREATE INDEX head_file_index on head_file_table(filename);
CREATE INDEX head_table_index on head_file_table(filename,path_file_id,checksum);

